@@ -1722,7 +1722,6 @@ def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, dr
     safe_r[:] = safe_rate
     start = 1000
     floor = 0.8
-
     dates = risky_r.index
     n_steps = len(dates)
     account_value = start
@@ -1738,7 +1737,7 @@ def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, dr
         if drawdown is not None :
             peak = np.maximum(account_value, peak)
             floor_value = peak * (1-drawdown)
-        cushion = (account_value - floor_value) / account_value
+        cushion = np.maximum((account_value - floor_value) / account_value,0.)
         risky_w = m * cushion
         risky_w = np.minimum(risky_w, 1.)
         risky_w = np.maximum(risky_w, 0.)
@@ -1746,7 +1745,7 @@ def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, dr
         risky_alloc = account_value * risky_w
         safe_alloc = account_value * safe_w
         ## update the account value
-        account_value = risky_alloc * (1 + risky_r.iloc[step]) + safe_alloc * (1 + safe_r.iloc[step])
+        account_value = risky_alloc * (1 + risky_r.iloc[step,0]) + safe_alloc * (1 + safe_r.iloc[step,0])
         ## save the values
         cushion_history.iloc[step] = cushion
         risky_w_history.iloc[step] = risky_w
@@ -1763,4 +1762,4 @@ def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, dr
         'floor' : floor,
         'risky_r' : risky_r,
         'safe_r' : safe_r}
-    return backtest_result
\ No newline at end of file
+    return backtest_result
